==> avr_crossworks_1_2_win.zip: avr/include/avr.h <==
#ifndef __avr_h__
#define __avr_h__

#define AT76C         13

#define AT90CAN128    1
#define AT90PWM2      2
#define AT90PWM3      3

#define AT90S1200     4
#define AT90S2313     5
#define AT90S2323     6
#define AT90S2343     7
#define AT90S4414     8
#define AT90S4433     9
#define AT90S4434     10
#define AT90S8515     11
#define AT90S8535     12

#define ATmega128     100
#define ATmega16      101
#define ATmega161     102
#define ATmega162     103
#define ATmega163     104
#define ATmega165     105
#define ATmega168     106
#define ATmega169     107
#define ATmega2560    108
#define ATmega2561    109
#define ATmega32      110
#define ATmega323     111
#define ATmega325     112
#define ATmega3250    113
#define ATmega329     114
#define ATmega3290    115
#define ATmega406     116
#define ATmega48      117
#define ATmega64      118
#define ATmega644     119
#define ATmega645     120
#define ATmega6450    121
#define ATmega649     122
#define ATmega6490    123
#define ATmega8       124
#define ATmega8515    125
#define ATmega8535    126
#define ATmega88      127

#define ATtiny11      200
#define ATtiny12      201
#define ATtiny13      202
#define ATtiny15      203
#define ATtiny22      204
#define ATtiny2313    205
#define ATtiny24      206
#define ATtiny25      207
#define ATtiny26      208
#define ATtiny28      209
#define ATtiny45      210
#define ATtiny85      211

#if   (__TARGET_PROCESSOR == AT76C)
#include                <AT76C.h>

#elif   (__TARGET_PROCESSOR == AT90CAN128)
#include                <AT90CAN128.h>

#elif (__TARGET_PROCESSOR == AT90PWM2)
#include                <AT90PWM2.h>

#elif (__TARGET_PROCESSOR == AT90PWM3)
#include                <AT90PWM3.h>

#elif (__TARGET_PROCESSOR == AT90S1200)
#include                <AT90S1200.h>

#elif (__TARGET_PROCESSOR == AT90S2313)
#include                <AT90S2313.h>

#elif (__TARGET_PROCESSOR == AT90S2323)
#include                <AT90S2323.h>

#elif (__TARGET_PROCESSOR == AT90S2343)
#include                <AT90S2343.h>

#elif (__TARGET_PROCESSOR == AT90S4414)
#include                <AT90S4414.h>

#elif (__TARGET_PROCESSOR == AT90S4433)
#include                <AT90S4433.h>

#elif (__TARGET_PROCESSOR == AT90S4434)
#include                <AT90S4434.h>

#elif (__TARGET_PROCESSOR == AT90S8515)
#include                <AT90S8515.h>

#elif (__TARGET_PROCESSOR == AT90S8535)
#include                <AT90S8535.h>

#elif (__TARGET_PROCESSOR == ATmega128)
#include                <ATmega128.h>

#elif (__TARGET_PROCESSOR == ATmega16) 
#include                <ATmega16.h>

#elif (__TARGET_PROCESSOR == ATmega161)
#include                <ATmega161.h>

#elif (__TARGET_PROCESSOR == ATmega162)
#include                <ATmega162.h>

#elif (__TARGET_PROCESSOR == ATmega163)
#include                <ATmega163.h>

#elif (__TARGET_PROCESSOR == ATmega165)
#include                <ATmega165.h>

#elif (__TARGET_PROCESSOR == ATmega168)
#include                <ATmega168.h>

#elif (__TARGET_PROCESSOR == ATmega169)
#include                <ATmega169.h>

#elif (__TARGET_PROCESSOR == ATmega2560)
#include                <ATmega2560.h>

#elif (__TARGET_PROCESSOR == ATmega2561)
#include                <ATmega2561.h>

#elif (__TARGET_PROCESSOR == ATmega32)
#include                <ATmega32.h>

#elif (__TARGET_PROCESSOR == ATmega323)
#include                <ATmega323.h>

#elif (__TARGET_PROCESSOR == ATmega325)
#include                <ATmega325.h>

#elif (__TARGET_PROCESSOR == ATmega3250)
#include                <ATmega3250.h>

#elif (__TARGET_PROCESSOR == ATmega329)
#include                <ATmega329.h>

#elif (__TARGET_PROCESSOR == ATmega3290)
#include                <ATmega3290.h>

#elif (__TARGET_PROCESSOR == ATmega406)
#include                <ATmega406.h>

#elif (__TARGET_PROCESSOR == ATmega48)
#include                <ATmega48.h>

#elif (__TARGET_PROCESSOR == ATmega64)
#include                <ATmega64.h>

#elif (__TARGET_PROCESSOR == ATmega644)
#include                <ATmega644.h>

#elif (__TARGET_PROCESSOR == ATmega645)
#include                <ATmega645.h>

#elif (__TARGET_PROCESSOR == ATmega6450)
#include                <ATmega6450.h>

#elif (__TARGET_PROCESSOR == ATmega649)
#include                <ATmega649.h>

#elif (__TARGET_PROCESSOR == ATmega6490)
#include                <ATmega6490.h>

#elif (__TARGET_PROCESSOR == ATmega8)
#include                <ATmega8.h>

#elif (__TARGET_PROCESSOR == ATmega8515)
#include                <ATmega8515.h>

#elif (__TARGET_PROCESSOR == ATmega8535)
#include                <ATmega8535.h>

#elif (__TARGET_PROCESSOR == ATmega88)
#include                <ATmega88.h>

#elif (__TARGET_PROCESSOR == ATtiny11)
#include                <ATtiny11.h>

#elif (__TARGET_PROCESSOR == ATtiny12)
#include                <ATtiny12.h>

#elif (__TARGET_PROCESSOR == ATtiny13)
#include                <ATtiny13.h>

#elif (__TARGET_PROCESSOR == ATtiny15)
#include                <ATtiny15.h>

#elif (__TARGET_PROCESSOR == ATtiny22)
#include                <ATtiny22.h>

#elif (__TARGET_PROCESSOR == ATtiny2313)
#include                <ATtiny2313.h>

#elif (__TARGET_PROCESSOR == ATtiny24)
#include                <ATtiny24.h>

#elif (__TARGET_PROCESSOR == ATtiny25)
#include                <ATtiny25.h>

#elif (__TARGET_PROCESSOR == ATtiny26)
#include                <ATtiny26.h>

#elif (__TARGET_PROCESSOR == ATtiny28)
#include                <ATtiny28.h>

#elif (__TARGET_PROCESSOR == ATtiny45)
#include                <ATtiny45.h>

#elif (__TARGET_PROCESSOR == ATtiny85)
#include                <ATtiny85.h>

#endif

#define __IOADDRESS(SFRADDRESS) ((SFRADDRESS)-0x20)

#endif

==> avr_crossworks_1_3_win.zip: avr/include/avr.h <==
#ifndef __avr_h__
#define __avr_h__

#define AT76C         10

#define AT90CAN128    30
#define AT90CAN32     31
#define AT90CAN64     32

#define AT90PWM2      50
#define AT90PWM3      51

#define AT90S1200     90
#define AT90S2313     91
#define AT90S2323     92
#define AT90S2343     93
#define AT90S4414     94
#define AT90S4433     95
#define AT90S4434     96
#define AT90S8515     97
#define AT90S8535     98

#define ATmega128     100
#define ATmega1280    101
#define ATmega1281    102
#define ATmega16      103
#define ATmega161     104
#define ATmega162     105
#define ATmega163     106
#define ATmega165     107
#define ATmega168     108
#define ATmega169     109
#define ATmega2560    110
#define ATmega2561    111
#define ATmega32      112
#define ATmega323     113
#define ATmega325     114
#define ATmega3250    115
#define ATmega329     116
#define ATmega3290    117
#define ATmega406     118
#define ATmega48      119
#define ATmega64      120
#define ATmega640     121
#define ATmega644     122
#define ATmega645     123
#define ATmega6450    124
#define ATmega649     125
#define ATmega6490    126
#define ATmega8       127
#define ATmega8515    128
#define ATmega8535    129
#define ATmega88      130

#define ATtiny11      200
#define ATtiny12      201
#define ATtiny13      202
#define ATtiny15      203
#define ATtiny22      204
#define ATtiny2313    205
#define ATtiny24      206
#define ATtiny25      207
#define ATtiny26      208
#define ATtiny28      209
#define ATtiny45      210
#define ATtiny85      211

#if   (__TARGET_PROCESSOR == AT76C)
#include                <AT76C.h>

#elif (__TARGET_PROCESSOR == AT90CAN128)
#include                <AT90CAN128.h>

#elif (__TARGET_PROCESSOR == AT90CAN32)
#include                <AT90CAN32.h>

#elif (__TARGET_PROCESSOR == AT90CAN64)
#include                <AT90CAN64.h>

#elif (__TARGET_PROCESSOR == AT90PWM2)
#include                <AT90PWM2.h>

#elif (__TARGET_PROCESSOR == AT90PWM3)
#include                <AT90PWM3.h>

#elif (__TARGET_PROCESSOR == AT90S1200)
#include                <AT90S1200.h>

#elif (__TARGET_PROCESSOR == AT90S2313)
#include                <AT90S2313.h>

#elif (__TARGET_PROCESSOR == AT90S2323)
#include                <AT90S2323.h>

#elif (__TARGET_PROCESSOR == AT90S2343)
#include                <AT90S2343.h>

#elif (__TARGET_PROCESSOR == AT90S4414)
#include                <AT90S4414.h>

#elif (__TARGET_PROCESSOR == AT90S4433)
#include                <AT90S4433.h>

#elif (__TARGET_PROCESSOR == AT90S4434)
#include                <AT90S4434.h>

#elif (__TARGET_PROCESSOR == AT90S8515)
#include                <AT90S8515.h>

#elif (__TARGET_PROCESSOR == AT90S8535)
#include                <AT90S8535.h>

#elif (__TARGET_PROCESSOR == ATmega128)
#include                <ATmega128.h>

#elif (__TARGET_PROCESSOR == ATmega1280)
#include                <ATmega1280.h>

#elif (__TARGET_PROCESSOR == ATmega1281)
#include                <ATmega1281.h>

#elif (__TARGET_PROCESSOR == ATmega16) 
#include                <ATmega16.h>

#elif (__TARGET_PROCESSOR == ATmega161)
#include                <ATmega161.h>

#elif (__TARGET_PROCESSOR == ATmega162)
#include                <ATmega162.h>

#elif (__TARGET_PROCESSOR == ATmega163)
#include                <ATmega163.h>

#elif (__TARGET_PROCESSOR == ATmega165)
#include                <ATmega165.h>

#elif (__TARGET_PROCESSOR == ATmega168)
#include                <ATmega168.h>

#elif (__TARGET_PROCESSOR == ATmega169)
#include                <ATmega169.h>

#elif (__TARGET_PROCESSOR == ATmega2560)
#include                <ATmega2560.h>

#elif (__TARGET_PROCESSOR == ATmega2561)
#include                <ATmega2561.h>

#elif (__TARGET_PROCESSOR == ATmega32)
#include                <ATmega32.h>

#elif (__TARGET_PROCESSOR == ATmega323)
#include                <ATmega323.h>

#elif (__TARGET_PROCESSOR == ATmega325)
#include                <ATmega325.h>

#elif (__TARGET_PROCESSOR == ATmega3250)
#include                <ATmega3250.h>

#elif (__TARGET_PROCESSOR == ATmega329)
#include                <ATmega329.h>

#elif (__TARGET_PROCESSOR == ATmega3290)
#include                <ATmega3290.h>

#elif (__TARGET_PROCESSOR == ATmega406)
#include                <ATmega406.h>

#elif (__TARGET_PROCESSOR == ATmega48)
#include                <ATmega48.h>

#elif (__TARGET_PROCESSOR == ATmega64)
#include                <ATmega64.h>

#elif (__TARGET_PROCESSOR == ATmega640)
#include                <ATmega640.h>

#elif (__TARGET_PROCESSOR == ATmega644)
#include                <ATmega644.h>

#elif (__TARGET_PROCESSOR == ATmega645)
#include                <ATmega645.h>

#elif (__TARGET_PROCESSOR == ATmega6450)
#include                <ATmega6450.h>

#elif (__TARGET_PROCESSOR == ATmega649)
#include                <ATmega649.h>

#elif (__TARGET_PROCESSOR == ATmega6490)
#include                <ATmega6490.h>

#elif (__TARGET_PROCESSOR == ATmega8)
#include                <ATmega8.h>

#elif (__TARGET_PROCESSOR == ATmega8515)
#include                <ATmega8515.h>

#elif (__TARGET_PROCESSOR == ATmega8535)
#include                <ATmega8535.h>

#elif (__TARGET_PROCESSOR == ATmega88)
#include                <ATmega88.h>

#elif (__TARGET_PROCESSOR == ATtiny11)
#include                <ATtiny11.h>

#elif (__TARGET_PROCESSOR == ATtiny12)
#include                <ATtiny12.h>

#elif (__TARGET_PROCESSOR == ATtiny13)
#include                <ATtiny13.h>

#elif (__TARGET_PROCESSOR == ATtiny15)
#include                <ATtiny15.h>

#elif (__TARGET_PROCESSOR == ATtiny22)
#include                <ATtiny22.h>

#elif (__TARGET_PROCESSOR == ATtiny2313)
#include                <ATtiny2313.h>

#elif (__TARGET_PROCESSOR == ATtiny24)
#include                <ATtiny24.h>

#elif (__TARGET_PROCESSOR == ATtiny25)
#include                <ATtiny25.h>

#elif (__TARGET_PROCESSOR == ATtiny26)
#include                <ATtiny26.h>

#elif (__TARGET_PROCESSOR == ATtiny28)
#include                <ATtiny28.h>

#elif (__TARGET_PROCESSOR == ATtiny45)
#include                <ATtiny45.h>

#elif (__TARGET_PROCESSOR == ATtiny85)
#include                <ATtiny85.h>

#endif

#define __IOADDRESS(SFRADDRESS) ((SFRADDRESS)-0x20)

#endif
